@@ -30,14 +30,13 @@ class TaskWrapper:
     def done(self):
         return self.task._finished
 
+    @property
+    def _finished(self):
+        return self.task._finished
 
-class FakeTaskWrapper:
-
-    def kill(self):
-        pass
-
-    def done(self):
-        return True
+    @property
+    def _outcome(self):
+        return self.task._outcome
 
 
 class KillableEvent:
@@ -82,6 +81,9 @@ class TaskHelper:
         self.events.add(event)
         return event
 
+    def Join(self, task):
+        return triggers.Join(task.task)
+
     @cocotb.coroutine
     async def RisingEdge(self, signal, kill_callback=None):
         await triggers.RisingEdge(signal)
@@ -108,7 +110,7 @@ class TaskHelper:
             task = cocotb.fork(coroutine)
             return TaskWrapper(forked_helper, task)
         else:
-            return FakeTaskWrapper()
+            raise KilledError
 
     @cocotb.coroutine
     async def add(self, needs_helper, name=None):
@@ -119,9 +121,12 @@ class TaskHelper:
             self.name = name
             new_helper = TaskHelper(name=name)
             self.child_helpers.append(new_helper)
-            await needs_helper(new_helper)
+            value = await needs_helper(new_helper)
             if self.killed:
                 raise KilledError
+            return value
+        else:
+            raise KilledError
 
     def kill(self, prefix=''):
         self._killed = True
@@ -147,7 +152,7 @@ def killable(coroutine):
         @wraps(coroutine)
         async def wrapper(helper):
             try:
-                await coroutine(helper, *args, **kwargs)
+                return await coroutine(helper, *args, **kwargs)
                 helper.finish()
             except KilledError:
                 pass
